@@ -7,4 +7,5 @@ except DistributionNotFound:
 
 __author__ = "Raphael Quast"
 
-from .eomaps import Maps
+
+from .eomaps import Maps, MapsGrid
